@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License along with
  * this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-#include "libfswatch/libfswatch_config.h"
+#include <libfswatch/libfswatch_config.h>
 #include <memory>
 #include <unistd.h> // isatty()
 #include <cstdio> // fileno()
@@ -22,9 +22,7 @@
 #include "libfswatch/gettext_defs.h"
 #include "libfswatch_exception.hpp"
 #include "libfswatch/c/libfswatch_log.h"
-#  ifdef HAVE_CXX_MUTEX
-#    include <mutex>
-#  endif
+#include <mutex>
 
 namespace fsw
 {
@@ -78,6 +76,10 @@ namespace fsw
     flags.push_back({kFSEventStreamEventFlagItemIsLastHardlink, fsw_event_flag::PlatformSpecific});
 #endif
 
+#ifdef HAVE_MACOS_GE_10_13
+    flags.push_back({kFSEventStreamEventFlagItemCloned, fsw_event_flag::PlatformSpecific});
+#endif
+
     return flags;
   }
 
@@ -92,9 +94,7 @@ namespace fsw
 
   void fsevents_monitor::run()
   {
-#ifdef HAVE_CXX_MUTEX
     std::unique_lock<std::mutex> run_loop_lock(run_mutex);
-#endif
 
     if (stream) return;
 
@@ -122,23 +122,19 @@ namespace fsw
       throw libfsw_exception(_("Event stream could not be created."));
 
     // Creating dispatch queue
-    fsevents_queue = dispatch_queue_create("fswatch_event_queue", NULL);
+    fsevents_queue = dispatch_queue_create("fswatch_event_queue", nullptr);
     FSEventStreamSetDispatchQueue(stream, fsevents_queue);
 
     FSW_ELOG(_("Starting event stream...\n"));
     FSEventStreamStart(stream);
 
-#ifdef HAVE_CXX_MUTEX
     run_loop_lock.unlock();
-#endif
 
     for(;;)
     {
-#ifdef HAVE_CXX_MUTEX
       run_loop_lock.lock();
       if (should_stop) break;
       run_loop_lock.unlock();
-#endif
 
       std::this_thread::sleep_for(std::chrono::milliseconds((long long) (latency * 1000)));
     }
@@ -194,9 +190,25 @@ namespace fsw
 
     for (size_t i = 0; i < numEvents; ++i)
     {
+#if defined(HAVE_MACOS_GE_10_13)
+      auto path_info_dict = static_cast<CFDictionaryRef>(CFArrayGetValueAtIndex((CFArrayRef) eventPaths,
+                                                                                i));
+      auto path = static_cast<CFStringRef>(CFDictionaryGetValue(path_info_dict,
+                                                                kFSEventStreamEventExtendedDataPathKey));
+      auto cf_inode = static_cast<CFNumberRef>(CFDictionaryGetValue(path_info_dict,
+                                                                    kFSEventStreamEventExtendedFileIDKey));
+      unsigned long inode;
+      CFNumberGetValue(cf_inode, kCFNumberLongType, &inode);
+      events.emplace_back(std::string(CFStringGetCStringPtr(path, kCFStringEncodingUTF8)),
+                          curr_time,
+                          decode_flags(eventFlags[i]),
+                          inode);
+
+#else
       events.emplace_back(((char **) eventPaths)[i],
                           curr_time,
                           decode_flags(eventFlags[i]));
+#endif
     }
 
     if (!events.empty())
@@ -226,6 +238,10 @@ namespace fsw
 
     FSEventStreamCreateFlags streamFlags = kFSEventStreamCreateFlagFileEvents;
     if (this->no_defer()) streamFlags |= kFSEventStreamCreateFlagNoDefer;
+#if defined (HAVE_MACOS_GE_10_13)
+    streamFlags |= kFSEventStreamCreateFlagUseExtendedData;
+    streamFlags |= kFSEventStreamCreateFlagUseCFTypes;
+#endif
 
     FSW_ELOG(_("Creating FSEvent stream...\n"));
     stream = FSEventStreamCreate(nullptr,
