@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015 Enrico M. Crisostomo
+ * Copyright (c) 2015-2021 Enrico M. Crisostomo
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -13,19 +13,34 @@
  * You should have received a copy of the GNU General Public License along with
  * this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-#ifdef HAVE_CONFIG_H
-#  include "libfswatch_config.h"
-#endif
-
 #include "cevent.h"
 #include <cstdlib>
 #include <cstring>
-#include "../c++/event.hpp"
-#include "../c++/libfswatch_exception.hpp"
+#include "libfswatch/c++/event.hpp"
+#include "libfswatch/c++/libfswatch_exception.hpp"
 
 using namespace std;
 using namespace fsw;
 
+const fsw_event_flag FSW_ALL_EVENT_FLAGS[] =
+  {
+    NoOp,
+    PlatformSpecific,
+    Created,
+    Updated,
+    Removed,
+    Renamed,
+    OwnerModified,
+    AttributeModified,
+    MovedFrom,
+    MovedTo,
+    IsFile,
+    IsDir,
+    IsSymLink,
+    Link,
+    Overflow
+  };
+
 FSW_STATUS fsw_get_event_flag_by_name(const char *name, fsw_event_flag *flag)
 {
   try
@@ -34,7 +49,7 @@ FSW_STATUS fsw_get_event_flag_by_name(const char *name, fsw_event_flag *flag)
 
     return FSW_OK;
   }
-  catch (const libfsw_exception& ex)
+  catch (const libfsw_exception&)
   {
     return FSW_ERR_UNKNOWN_VALUE;
   }
@@ -43,7 +58,7 @@ FSW_STATUS fsw_get_event_flag_by_name(const char *name, fsw_event_flag *flag)
 char *fsw_get_event_flag_name(const fsw_event_flag flag)
 {
   string name = event::get_event_flag_name(flag);
-  char *cstr = static_cast<char *>(malloc(name.size() + 1));
+  auto cstr = static_cast<char *>(malloc(name.size() + 1));
 
   if (cstr == nullptr) return nullptr;
 
